@@ -130,7 +130,8 @@ class LinkedinJSAPIOAuth(BaseLinkedinAuth, BaseOAuth1):
             else:
                 raise
 
-        return super(LinkedinJSAPIOAuth, self).do_auth(access_token)
+        return super(LinkedinJSAPIOAuth, self).do_auth(access_token, *args,
+                                                       **kwargs)
 
     def access_token(self, token):
         """Return request for access token value"""
